=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2009-07-06 08:10:16 +0000
+++ bzrlib/builtins.py	2009-07-06 08:39:58 +0000
@@ -5255,7 +5255,21 @@
             stacked_on=None):
         directory = bzrdir.BzrDir.open(location)
         if stacked_on is not None:
-            pass
+            branch = directory.open_branch()
+            # it may be a path relative to the cwd or a url; the branch wants
+            # a path relative to itself...
+            on_url = urlutils.relative_url(branch.base,
+                urlutils.normalize_url(stacked_on))
+            branch.lock_write()
+            try:
+                branch.set_stacked_on_url(on_url)
+                if not is_quiet():
+                    self.outf.write(
+                        "%s is now stacked on %s\n"
+                        % (branch.base,
+                           branch.get_stacked_on_url()))
+            finally:
+                branch.unlock()
         # At the moment you can use --stacked-on and a different
         # reconfiguration shape at the same time; there seems no good reason
         # to ban it.

=== modified file 'bzrlib/tests/blackbox/test_reconfigure.py'
--- bzrlib/tests/blackbox/test_reconfigure.py	2009-07-06 08:10:16 +0000
+++ bzrlib/tests/blackbox/test_reconfigure.py	2009-07-06 08:39:58 +0000
@@ -190,8 +190,15 @@
         branch_1 = self.make_branch('b1', format='2a')
         branch_2 = self.make_branch('b2', format='2a')
         out, err = self.run_bzr('reconfigure --stacked-on b2 b1')
+        self.assertContainsRe(out,
+            '^.*/b1/ is now stacked on ../b2\n')
+        self.assertEquals('', err)
+        # It should be given a relative URL to the destination, if possible,
+        # because that's most likely to work across different transports
         self.assertEquals(branch_1.get_stacked_on_url(),
-                branch_2.location)
+            '../b2')
 
-    # XXX: Needs a test for reconfiguring stacking and shape at the same time.
+    # XXX: Needs a test for reconfiguring stacking and shape at the same time;
+    # no branch at location; stacked-on is not a branch; quiet mode; output in
+    # non-quiet mode; handling of URLs relative to the stacked branch.
     # -- mbp 20090706

